# BillingOptions


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**credit_memo_reason_code** | **str** | A code identifying the reason for the credit memo transaction that is generated by the request. The value must be an existing reason code. If you do not pass the field or pass the field with empty value, Zuora uses the default reason code. | [optional] 
**document_date** | **date** | The invoice date displayed on the invoice.  | [optional] 
**generate_draft_invoice** | **bool** | Indicates if the current request needs to generate a draft invoice.  Values are:  * &#x60;true&#x60; * &#x60;false&#x60; (default)  | [optional] 
**target_date** | **date** | Date through which to calculate charges if an invoice is generated. See [What is a Target Date?](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/G_Bill_Runs/Creating_Bill_Runs#What_is_a_Target_Date.3F).  | [optional] 
**charge_type_to_exclude** | [**List[ChargeType]**](ChargeType.md) | The types of the charges to be excluded from the generation of billing documents.  | [optional] 

## Example

```python
from zuora_sdk.models.billing_options import BillingOptions

# TODO update the JSON string below
json = "{}"
# create an instance of BillingOptions from a JSON string
billing_options_instance = BillingOptions.from_json(json)
# print the JSON string representation of the object
print(BillingOptions.to_json())

# convert the object into a dict
billing_options_dict = billing_options_instance.to_dict()
# create an instance of BillingOptions from a dict
billing_options_from_dict = BillingOptions.from_dict(billing_options_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


